package org.qatools.factory;

import java.util.LinkedList;
import java.util.List;
import org.apache.log4j.Logger;
import org.qatools.local.LocalFile;
import org.qatools.local.LocalFileUtil;
import org.qatools.util.ListUtil;

public class DataGenerator extends QAToolsFactory {
    private static Logger logger = Logger.getLogger(DataGenerator.class);
    private static List<String> firstnames;
    private static List<String> malenames;
    private static List<String> femalenames;
    private static List<String> lastnames;    
    private static List<String> cities;
    private static List<String> countries;
    private static List<String> emails;
    private static List<String> phones;
    private static List<String> street_addresses;
    private static List<String> companies;
    private static List<String> departments;
    private static List<String> quotes;
    private static List<String> excuses;
    
    static {
    	try {
    		malenames = LocalFileUtil.getLines(new LocalFile("src/main/resources/data/", "firstnames.male.txt"));
    		femalenames = LocalFileUtil.getLines(new LocalFile("src/main/resources/data/", "firstnames.female.txt"));
    		lastnames = LocalFileUtil.getLines(new LocalFile("src/main/resources/data/", "lastnames.txt"));
    		cities = LocalFileUtil.getLines(new LocalFile("src/main/resources/data/", "cities.txt"));
    		countries = LocalFileUtil.getLines(new LocalFile("src/main/resources/data/", "countries.txt"));
    		emails = LocalFileUtil.getLines(new LocalFile("src/main/resources/data/", "emails.txt"));
    		phones = LocalFileUtil.getLines(new LocalFile("src/main/resources/data/", "phones.txt"));
    		street_addresses = LocalFileUtil.getLines(new LocalFile("src/main/resources/data/", "street-addresses.txt"));
    		companies = LocalFileUtil.getLines(new LocalFile("src/main/resources/data/", "companies.txt"));
    		departments = LocalFileUtil.getLines(new LocalFile("src/main/resources/data/", "departments.txt"));
            quotes = LocalFileUtil.getLines(new LocalFile("src/main/resources/data/", "quotes.txt"));
            excuses = LocalFileUtil.getLines(new LocalFile("src/main/resources/data/", "excuses.txt"));
    		
            firstnames = new LinkedList<String>();
            firstnames.addAll (malenames);
            firstnames.addAll (femalenames);
            

            
            
            logger.debug("Loaded first names - " + firstnames.size());
            logger.debug("Loaded male names - " + malenames.size());
    		logger.debug("Loaded female names - " + femalenames.size());
    		logger.debug("Loaded last names - " + lastnames.size());
            logger.debug("Loaded cities - " + cities.size());
            logger.debug("Loaded countries - " + countries.size());
            logger.debug("Loaded emails - " + emails.size());
            logger.debug("Loaded phones - " + phones.size());
            logger.debug("Loaded street-addresses - " + street_addresses.size());
            logger.debug("Loaded companies - " + companies.size());
            logger.debug("Loaded departments - " + departments.size());
            logger.debug("Loaded quotes - " + quotes.size());
            logger.debug("Loaded excuses - " + excuses.size());

    	
    	} catch (Exception ex) {
    		ex.printStackTrace();    		
    	}
    }
    
	// --------------------------------------------------------
	// ----- first names - male or femail
	// --------------------------------------------------------
	
    /**
     * 
     * @return
     */
    public static String getRandomFirstname() {
        return ListUtil.getRandom(firstnames);
    }
    
    /**
     * 
     * @param num
     * @return
     */
    public static List<String> getRandomFirstnames(int num) {
        return ListUtil.getRandoms(firstnames, num);
    }

    // --------------------------------------------------------
    // ----- male names
    // --------------------------------------------------------

    /**
	 * 
	 * @return
	 */
	public static String getRandomMaleFirstname() {
		return ListUtil.getRandom(malenames);
	}
	
	/**
	 * 
	 * @param num
	 * @return
	 */
	public static List<String> getRandomMaleFirstnames(int num) {
		return ListUtil.getRandoms(malenames, num);
	}
	

	// --------------------------------------------------------
	// ----- female names
	// --------------------------------------------------------
	
	/**
	 * 
	 * @return
	 */
	public static String getRandomFemaleFirstname() {
		return ListUtil.getRandom(femalenames);
	}
	
	/**
	 * 
	 * @param num
	 * @return
	 */
	public static List<String> getRandomFemaleFirstnames(int num) {
		return ListUtil.getRandoms(femalenames, num);
	}
	

	// --------------------------------------------------------
	// ----- last names
	// --------------------------------------------------------
	
	/**
	 * 
	 * @return
	 */
	public static String getRandomLastname() {
		return ListUtil.getRandom(lastnames);
	}
	
	/**
	 * 
	 * @param num
	 * @return
	 */
	public static List<String> getRandomLastnames(int num) {
		return ListUtil.getRandoms(lastnames, num);
	}
	
	
    // --------------------------------------------------------
    // ----- cities
    // --------------------------------------------------------

	   /**
     * 
     * @return
     */
    public static String getRandomCity() {
        return ListUtil.getRandom(cities);
    }
    
    /**
     * 
     * @param num
     * @return
     */
    public static List<String> getRandomCities(int num) {
        return ListUtil.getRandoms(cities, num);
    }


    // --------------------------------------------------------
    // ----- countries
    // --------------------------------------------------------

    /**
     * 
     * @return
     */
    public static String getRandomCountry() {
        return ListUtil.getRandom(countries);
    }
    
    /**
     * 
     * @param num
     * @return
     */
    public static List<String> getRandomCountires(int num) {
        return ListUtil.getRandoms(countries, num);
    }

    // --------------------------------------------------------
    // ----- emails
    // --------------------------------------------------------

    /**
     * 
     * @return
     */
    public static String getRandomEmail() {
        return ListUtil.getRandom(emails);
    }
    
    /**
     * 
     * @param num
     * @return
     */
    public static List<String> getRandomEmails(int num) {
        return ListUtil.getRandoms(emails, num);
    }


    // --------------------------------------------------------
    // ----- phones
    // --------------------------------------------------------

    /**
     * 
     * @return
     */
    public static String getRandomPhone() {
        return ListUtil.getRandom(phones);
    }
    
    /**
     * 
     * @param num
     * @return
     */
    public static List<String> getRandomPhones(int num) {
        return ListUtil.getRandoms(phones, num);
    }


    // --------------------------------------------------------
    // ----- street_addresses
    // --------------------------------------------------------

    /**
     * 
     * @return
     */
    public static String getRandomStreetAddress() {
        return ListUtil.getRandom(street_addresses);
    }
    
    /**
     * 
     * @param num
     * @return
     */
    public static List<String> getRandomStreetAddresses(int num) {
        return ListUtil.getRandoms(street_addresses, num);
    }


    // --------------------------------------------------------
    // ----- companies
    // --------------------------------------------------------

    /**
     * 
     * @return
     */
    public static String getRandomCompany() {
        return ListUtil.getRandom(companies);
    }
    
    /**
     * 
     * @param num
     * @return
     */
    public static List<String> getRandomCompanies(int num) {
        return ListUtil.getRandoms(companies, num);
    }
    
    // --------------------------------------------------------
    // ----- departments
    // --------------------------------------------------------

    /**
     * 
     * @return
     */
    public static String getRandomDepartment() {
        return ListUtil.getRandom(departments);
    }
    
    /**
     * 
     * @param num
     * @return
     */
    public static List<String> getRandomDepartments(int num) {
        return ListUtil.getRandoms(departments, num);
    }


    // --------------------------------------------------------
    // ----- quotes
    // --------------------------------------------------------

    /**
     * 
     * @return
     */
    public static String getRandomQuote() {
        return ListUtil.getRandom(quotes);
    }
    
    /**
     * 
     * @param num
     * @return
     */
    public static List<String> getRandomQuotes(int num) {
        return ListUtil.getRandoms(quotes, num);
    }

    // --------------------------------------------------------
    // ----- excuses
    // --------------------------------------------------------

    /**
     * 
     * @return
     */
    public static String getRandomExcuse() {
        return ListUtil.getRandom(excuses);
    }
    
    /**
     * 
     * @param num
     * @return
     */
    public static List<String> getRandomExcuses(int num) {
        return ListUtil.getRandoms(excuses, num);
    }



    
    
	

}